from setuptools import setup

setup(
    name='tuchuang',
    version='3.0.0',
    description='一个免费而简单图床',
    author='Python学霸',
    author_email='python@xueba.com',
    packages=['tuchuang'],
    install_requires=['requests', 'json'],
)